@@ -1,4 +1,4 @@
-// $Id: bue.ctrl.js,v 1.3.2.5 2010/03/03 13:58:49 ufku Exp $
+// $Id: bue.ctrl.js,v 1.3.2.6 2010/11/08 07:10:25 ufku Exp $
 
 //Register button accesskeys as Ctrl shortcuts.
 //Requires: none
@@ -18,7 +18,7 @@ BUE.preprocess.ctrl = function(E, $) {
   });
 
   //register ctrl shortcuts for the editor.
-  $(E.textArea).keydown(function(e) {
+  $(E.textArea).bind('keydown.bue', function(e) {
     if (e.ctrlKey && !e.shiftKey && !e.originalEvent.altKey && E.ctrlKeys[e.keyCode]) {
       E.ctrlKeys[e.keyCode].click();
       //Opera needs supression of keypress.
